# Mattermost

Mattermost is an open source, on-prem Slack-alternative. 

It offers modern communication from behind your firewall, including messaging and file sharing across PCs and phones with archiving and instant search.

## All team communication in one place, searchable and accessible anywhere

Please see the [features pages of the Mattermost website](http://www.mattermost.org/features/) for images and further description of the functionality listed below: 

#### Sharing Messaging and Files

- Send messages, comments, files and images across public, private and 1-1 channels
- Personalize notifications for unreads and mentions by channel and keyword
- Use #hashtags to tag and find messages, discussions and files

#### Archiving and Search 

- Import Slack user accounts and channel archives
- Search public and private channels for historical messages and comments 
- View recent mentions of your name, username, nickname, and custom search terms

#### Anywhere Access

- Use Mattermost from web-enabled PCs and phones
- Attach sound, video and image files from mobile devices 
- Define team-specific branding and color themes across your devices

## Learn More

- [Product Vision and Target Audiences](http://www.mattermost.org/vision/) - What we're solving and for whom are we building
- [Mattermost Forum](http://forum.mattermost.org/) - For technical questions and answers
- [Issue Tracker](http://www.mattermost.org/filing-issues/) - For reporting bugs
- [Feature Ideas Forum](http://www.mattermost.org/feature-requests/) - For sharing ideas for future versions 
- [Contribution Guidelines](http://www.mattermost.org/contribute-to-mattermost/) - For contributing code or feedback to the project

Follow us on Twitter at [@MattermostHQ](https://twitter.com/mattermosthq).

## Installing Mattermost

There are multiple ways to install Mattermost depending on your needs. 

#### Quick Start Install for Product Evaluation 

- [Local Machine Install with Docker](doc/install/single-container-install.md) - Explore product functionality using a single-container Docker install on a local machine, including Mac OSX, Ubuntu, or Arch Linux). Optionally set up email and upgrade your instance using DockerHub. 

- [AWS EBS Install with Docker](doc/install/aws-ebs-setup.md) - Explore product functionality using a single-container Docker install for Amazon Web Services Elastic Beanstalk. Optionally set up email and upgrade your instance using DockerHub. 

#### Development Install 

- [Developer Machine Setup](doc/install/dev-setup.md) - Setup your local machine development environment using Docker on Mac OSX or Ubuntu. Pull the latest stable release or pull the latest code from our development build. 

[![Build Status](https://travis-ci.org/mattermost/platform.svg?branch=master)](https://travis-ci.org/mattermost/platform)

#### Production Deployment

Prior to production installation, please review [Mattermost system requirements](doc/install/requirements.md). 

- [Production Install on Ubuntu 14.04](https://github.com/mattermost/platform/blob/release-1.0.0/doc/install/prod-ubuntu.md) - Install Mattermost for production environments. 

- [GitLab Mattermost Production Installation](https://gitlab.com/gitlab-org/gitlab-mattermost) - Install Mattermost for production environments bundled with GitLab, a leading open source Git repository, using an omnibus package for Ubuntu 12.04, Ubuntu 14.04, Debian 7, Debian 8, and CentOS 6 (and RedHat/Oracle/Scientific Linux 6), CentOS 7 (and RedHat/Oracle/Scientific Linux 7). 

For technical questions and answers, please visit the [Mattermost forum](http://forum.mattermost.org).

## Get Involved with Mattermost 

Joining the Mattermost community is a great way to build relationships with other talented and like-minded professionals, increase awareness of the interesting work you are doing, and sharpen your skills. Here are some of the ways that you can make a difference in the Mattermost ecosystem:

#### Discuss

- Visit the [Mattermost Forum](http://forum.mattermost.org/) for technical questions and answers. 
- [Join](https://groups.google.com/a/mattermost.com/forum/#!forum/general/join) the [Mattermost User Mailing List](https://groups.google.com/a/mattermost.com/forum/#!forum/general) for general, open-ended questions and software announcements. 
- [Join](https://groups.google.com/a/mattermost.com/forum/#!forum/developer/join) the [Mattermost Developers Mailing List](https://groups.google.com/a/mattermost.com/forum/#!forum/developer) for discussing contributing code to Mattermost. 

#### Review

- Share feedback on [Mattermost Design Feedback Requests](http://forum.mattermost.org/c/feature-ideas/specifications), which offer early previews of designs community comments and feedback. 
- Visit the [Feature Ideas Forum](http://mattermost.uservoice.com/forums/306457-general) and consider upvoting community feature ideas, which are reviewed for each monthly release.

#### Share

- Blog about your Mattermost experiences and use cases, either on your personal blog, the [Mattermost forum](http://forum.mattermost.org), or contribute a guest post to the [Mattermost blog](http://www.mattermost.org/category/blog/). If you write about Mattermost. please contact our community team at info@mattermost.com for help promoting your content.
- Tweet to share with your community and friends why you use Mattermost. Follow [@MattermostHQ](https://twitter.com/mattermosthq) on Twitter and conversations on [#mattermost](https://twitter.com/search?q=%23mattermost&src=typd).

#### Write

- As with most open source projects, Mattermost documentation is maintained in a public repository. You can propose changes by [submitting pull requests (no programming skills required)](http://forum.mattermost.org/t/help-improve-mattermost-documentation/194). We highly welcome you to add improvements, write guides and tutorials, and expand on sections. 
- Prior to contributing, please review [Mattermost Documentation Guidelines](http://www.mattermost.org/documentation-guidelines/), which include standards on writing Mattermost documentation for a global audience, who might not use English as their first language.

#### Contribute

- Share [feature ideas](http://www.mattermost.org/feature-requests/) with the Mattermost community
- Review the [Mattermost Code Contribution Guidelines](doc/developer/code-contribution.md) to submit patches for the core product
- Consider building tools that help developers and IT professionals manage Mattermost more effectively (API documentation coming in Beta2)

#### Have other ideas or suggestions?

If there’s some other way you’d like to contribute, please contact us at info@mattermost.com. We’d love to meet you!
